@@ -36,7 +36,7 @@ AVAILABLE FEATURES IN THE LIBRARY:
 
             save_to(file, prefix, func_name, choice) - file saver for code clarity.
 
-            file_handler(file) - handles the file extenstion upon import.
+            file_handler(file) - handles the file extension upon import.
 
     MONTECARLO (OBJECT)
     -------------------
@@ -62,10 +62,17 @@ AVAILABLE FEATURES IN THE LIBRARY:
     vandal.MCapp is an executable function that runs the Command Line Interface of the vandal MonteCarlo module.
         print(help(vandal.MCapp)) in order to see available features.
 
+    EOQapp (EXECUTABLE CLI MODULE)
+    -------------------------
+
+    vandal.EOQapp is an executable function that runs the Command Line Interface of the vandal EOQ module.
+        print(help(vandal.EOQapp)) in order to see available features.
+
 '''
 
 # ignore __pycache__ from forming inside the library directory.
 import sys
+from tokenize import Number
 sys.dont_write_bytecode = True
 
 # meta data imports from the vandal library.
@@ -81,6 +88,55 @@ from vandal.misc._meta import (
     __APPversion__,
 )
 
+# imports plugins.
+from vandal.plugins.metaclass import Meta
+from vandal.plugins.types import (
+    VandalType,
+    IntegerType,
+    FloatType,
+    NumberType,
+    ReturnType,
+    PrintType,
+    GraphType,
+    StringType,
+    ListType,
+    TupleType,
+    DictionaryType,
+    BooleanType,
+    NumberVector,
+    StringVector,
+    StringDictionary,
+    DictionaryVector,
+    NumberVectorAlike,
+    NumberArrayAlike,
+    AnyArrayAlike,
+    AnyVectorAlike,
+)
+
+# available types.
+__types__ = [
+    VandalType,
+    IntegerType,
+    FloatType,
+    NumberType,
+    ReturnType,
+    PrintType,
+    GraphType,
+    StringType,
+    ListType,
+    TupleType,
+    DictionaryType,
+    BooleanType,
+    NumberVector,
+    StringVector,
+    StringDictionary,
+    DictionaryVector,
+    NumberVectorAlike,
+    NumberArrayAlike,
+    AnyArrayAlike,
+    AnyVectorAlike,
+]
+
 # object and module imports.
 from vandal.hub import toolkit
 from vandal.objects.eoq import(
@@ -125,5 +181,6 @@ __all__ = [
     MonteCarlo,
     MCapp,
     EOQ,
+    EOQapp,
     Dijkstra,
 ]
