@@ -1,7 +1,9 @@
 # imports all relevant contents.
-from random import choice
 import vandal
-from vandal.objects import montecarlo
+from vandal.objects import (
+    montecarlo,
+    eoq,
+)
 
 # coloring.
 import colorama
