@@ -1,3 +1,28 @@
+# type hints and annotations.
+from vandal.plugins.metaclass import Meta
+from vandal.plugins.types import (
+    VandalType,
+    IntegerType,
+    FloatType,
+    NumberType,
+    ReturnType,
+    PrintType,
+    GraphType,
+    StringType,
+    ListType,
+    TupleType,
+    DictionaryType,
+    BooleanType,
+    NumberVector,
+    StringVector,
+    StringDictionary,
+    DictionaryVector,
+    NumberVectorAlike,
+    NumberArrayAlike,
+    AnyArrayAlike,
+    AnyVectorAlike,
+)
+
 # object that contains the required data.
 class Dijkstra:
 
@@ -6,14 +31,9 @@ class Dijkstra:
     (OBJECT INFO)
     -------------
 
-    vandal.Dijkstra - main class that contains the data of defined nodes, origin and the desired destination.
-
-    (OBJECT FUNCTIONS)
-    ------------------
-
-    eg. vandal.Dijkstra.function()
-
-        .execute() -  contains the data of defined nodes, origin and the desired destination, executes a Dijkstra algorithm route scan on a defined path.
+    eg. Dijkstra = vandal.Dijkstra()
+    
+    vandal.Dijkstra - main class that contains contains the data of defined nodes, origin and the desired destination.
         * takes 3 additional arguments.
             nodes - dictionary of dictionaries of nodes with their corelating weights.
 
@@ -23,12 +43,21 @@ class Dijkstra:
             'b':{'c':2,'d':4},
             'c':{'b':5,'d':4,'e':3},
             'd':{'e':5},
-            'e':{'d':6}
+            'e':{'d':6},
             }
 
             origin - origin node as a starting point.
             destination - destination node of the desired route.
 
+    (OBJECT FUNCTIONS)
+    ------------------
+
+    eg. vandal.Dijkstra.function()
+
+        .execute() - executes the Dijkstra algorithm on top of the defined data.
+            * takes 1 additional argument.
+                filtered (default: filtered = True) - filters the print option and leaves just the return object.
+
     '''
 
     # metadata of the used library.
@@ -45,28 +74,50 @@ class Dijkstra:
     )
 
     # initial launch.
-    def __init__(self):
-        pass
-
-    # class information.
-    def __str__(self):
-        return f'Dijkstra defining object that stores the configuration data for finding the path within {self.nodes} from {self.origin} => {self.destination}.'
-
-    # class information.
-    def __repr__(self):
-        return f'Dijkstra defining object that stores the configuration data for finding the path within {self.nodes} from {self.origin} => {self.destination}.'
-
-    # executes a Dijkstra algorithm route scan on a defined path.
-    def execute(self, nodes, origin, destination, log_summary = False):
+    def __init__(
+        self,
+        nodes : DictionaryType = None, 
+        origin : StringType = None, 
+        destination : StringType = None,
+        ) -> ReturnType:
+        
         self.nodes = nodes
         self.origin = origin
         self.destination = destination
-        self.log_summary = log_summary
-        print(f'Dijkstra has been set up for for finding the path from {self.origin} => {self.destination}.')
+        
+        return
+
+    # class information.
+    def __str__(
+        self,
+        ) -> StringType:
+
+        return f'Dijkstra defining object that stores the configuration data for finding the path within {self.nodes} from {self.origin} => {self.destination}.'
+
+    # class information.
+    def __repr__(
+        self,
+        ) -> StringType:
+
+        return f'Dijkstra defining object that stores the configuration data for finding the path within {self.nodes} from {self.origin} => {self.destination}.'
+
+    # executes a Dijkstra algorithm route scan on a defined path.
+    def execute(
+        self,
+        filtered : bool = True,
+        ) -> AnyArrayAlike:
+
+        import pandas as pd
+        import numpy as np
+
+        if filtered == False:
+            print(f'Dijkstra has been set up for for finding the path from {self.origin} => {self.destination}.')
+            
         Nodes = self.nodes
         preNode = {}
         optimal_distance = {}
         output_path = []
+
         for node in Nodes:
             optimal_distance[node] = float('inf')
         optimal_distance[self.origin] = 0
@@ -86,6 +137,7 @@ class Dijkstra:
             Nodes.pop(closestNode)
 
         liveNode = self.destination
+        
         while liveNode != self.origin:
             try:
                 output_path.insert(0, liveNode)
@@ -94,5 +146,17 @@ class Dijkstra:
                 print('Path unavailable.')
                 break
         output_path.insert(0, self.origin)
+
         if optimal_distance[self.destination] != float('inf'):
-            print('Optimal path: ' + str(output_path), '\nMinimal distance: ' + str(optimal_distance[self.destination]))
+            final_path = {'Optimal path' : [output_path], 'Minimal distance' : (optimal_distance[self.destination]),}
+            final_path = pd.DataFrame(final_path, index = ['Output'])
+            final_path = final_path.transpose() 
+
+            return final_path
+
+        else:
+            final_path = {'Optimal path' : [None], 'Minimal distance' : None,}
+            final_path = pd.DataFrame(final_path, index = ['Output'])
+            final_path = final_path.transpose() 
+
+            return final_path
\ No newline at end of file
