@@ -1,9 +1,33 @@
 # coloring.
-import colorama
 from colorama import Fore, init 
 
 init()
 
+# type hints and annotations.
+from vandal.plugins.metaclass import Meta
+from vandal.plugins.types import (
+    VandalType,
+    IntegerType,
+    FloatType,
+    NumberType,
+    ReturnType,
+    PrintType,
+    GraphType,
+    StringType,
+    ListType,
+    TupleType,
+    DictionaryType,
+    BooleanType,
+    NumberVector,
+    StringVector,
+    StringDictionary,
+    DictionaryVector,
+    NumberVectorAlike,
+    NumberArrayAlike,
+    AnyArrayAlike,
+    AnyVectorAlike,
+)
+
 # object that contains the calculation data.
 class EOQ:
 
@@ -12,7 +36,13 @@ class EOQ:
     (OBJECT INFO)
     -------------
 
-    vandal.EOQ - main class.
+    eg. EOQ = vandal.EOQ()
+
+    vandal.EOQ - main class that stores the data required for an EOQ simulation.
+        * takes 3 additional arguments.
+            annual_demand_quantity - integer of demanded quantity in a year.
+            order_fixed_cost - integer or float presenting the fixed cost of the order.
+            annual_holding_cost - cost of holding the goods in a year.
 
     (OBJECT FUNCTIONS)
     ------------------
@@ -20,11 +50,15 @@ class EOQ:
     eg. vandal.EOQ.function()
 
         .execute() - executes the calculation of EOQ over the defined parameters.
-        * takes 3 additional arguments.
-            annual_demand_quantity - integer of demanded quantity in a year.
-            order_fixed_cost - integer or float presenting the fixed cost of the order.
-            annual_holding_cost - cost of holding the goods in a year.
+            * takes 1 additional argument.
+                filtered (defualt: filtered = True) - filters the print option and leaves just the return object.
 
+    EOQapp (EXECUTABLE CLI MODULE)
+    -------------------------
+
+    vandal.EOQapp is an executable function that runs the Command Line Interface of the vandal EOQ module.
+        print(help(vandal.EOQapp)) in order to see available features.
+        
     '''
 
     # metadata of the used library.
@@ -41,26 +75,49 @@ class EOQ:
     )
 
     # initial launch.
-    def __init__(self):
-        pass
+    def __init__(
+        self,
+        annual_demand_quantity : NumberType = None,
+        order_fixed_cost : NumberType = None, 
+        annual_holding_cost : NumberType = None,
+    ) -> ReturnType:
 
-    # class information.
-    def __str__(self):
-        return f'EOQ defining object that contains annual demand quantity of {self.annual_demand_quantity} pieces, fixed cost of the order of {self.order_fixed_cost} and with the annual holding cost of {self.annual_holding_cost}.'
-
-    # class information.
-    def __repr__(self):
-        return f'EOQ defining object that contains annual demand quantity of {self.annual_demand_quantity} pieces, fixed cost of the order of {self.order_fixed_cost} and with the annual holding cost of {self.annual_holding_cost}.'
-
-    # executes the calculation of EOQ over the defined parameters.
-    def execute(self, annual_demand_quantity, order_fixed_cost, annual_holding_cost):
         self.annual_demand_quantity = annual_demand_quantity
         self.order_fixed_cost = order_fixed_cost
         self.annual_holding_cost = annual_holding_cost
-        print(Fore.GREEN + 'EOQ has been set up with annual demand quantity of ' + Fore.RESET + f'{self.annual_demand_quantity}' + Fore.GREEN + ' pieces, fixed cost of the order of ' + Fore.RESET + f'{self.order_fixed_cost}' + Fore.GREEN + ' and with the annual holding cost of ' + Fore.RESET + f'{self.annual_holding_cost}.')
+        
+        return
+
+    # class information.
+    def __str__(
+        self,
+        ) -> StringType:
+
+        return f'EOQ defining object that contains annual demand quantity of {self.annual_demand_quantity} pieces, fixed cost of the order of {self.order_fixed_cost} and with the annual holding cost of {self.annual_holding_cost}.'
+
+    # class information.
+    def __repr__(
+        self,
+        ) -> StringType:
+
+        return f'EOQ defining object that contains annual demand quantity of {self.annual_demand_quantity} pieces, fixed cost of the order of {self.order_fixed_cost} and with the annual holding cost of {self.annual_holding_cost}.'
+
+    # executes the calculation of EOQ over the defined parameters.
+    def execute(
+        self, 
+        filtered = True,
+        ) -> NumberType:
+
+        if filtered == False:
+            print(Fore.GREEN + 'EOQ has been set up with annual demand quantity of ' + Fore.RESET + f'{self.annual_demand_quantity}' + Fore.GREEN + ' pieces, fixed cost of the order of ' + Fore.RESET + f'{self.order_fixed_cost}' + Fore.GREEN + ' and with the annual holding cost of ' + Fore.RESET + f'{self.annual_holding_cost}.')
+        
         import math
         eoq = math.sqrt((((2 * self.annual_demand_quantity) * self.order_fixed_cost) / self.annual_holding_cost))
-        print(Fore.GREEN + 'EOQ is:', Fore.RESET, eoq)
+        eoq = round(eoq, 2)
+
+        if filtered == False:
+            print(Fore.GREEN + 'EOQ is:', Fore.RESET, eoq)
+
         return eoq
 
 def EOQapp():
@@ -74,6 +131,8 @@ def EOQapp():
         
     '''
 
+    print(Fore.YELLOW + 'EOQ app is initializing...', Fore.RESET)
+    
     # relevant imports.
     import os
     from vandal.misc._meta import (
@@ -86,12 +145,14 @@ def EOQapp():
     # greeting.
     print(Fore.YELLOW + '\n - vandal Command Line Interface Application © David Kundih -', __APPversion__)
     print(Fore.YELLOW + ' - vandal package version -', 'v',__version__, Fore.RESET, '\n')
-    EOQObj = EOQ()
-    adq = int(input('Enter the annual demand quantity: '))
-    ofc = int(input('Enter the fixed cost of the order: '))
-    ahc = int(input('Enter the annual holding cost: '))
+    
+    adq = float(input('Enter the annual demand quantity: '))
+    ofc = float(input('Enter the fixed cost of the order: '))
+    ahc = float(input('Enter the annual holding cost: '))
+
+    EOQObj = EOQ(annual_demand_quantity = adq, order_fixed_cost = ofc, annual_holding_cost = ahc)
     print('')
-    EOQObj.execute(annual_demand_quantity = adq, order_fixed_cost = ofc, annual_holding_cost = ahc)
+    EOQObj.execute(filtered = False)
 
 if __name__ == '__main__':
-    EOQapp()
\ No newline at end of file
+    EOQapp()
