@@ -1,9 +1,33 @@
 # coloring.
-import colorama
 from colorama import Fore, init 
 
 init()
 
+# type hints and annotations.
+from vandal.plugins.metaclass import Meta
+from vandal.plugins.types import (
+    VandalType,
+    IntegerType,
+    FloatType,
+    NumberType,
+    ReturnType,
+    PrintType,
+    GraphType,
+    StringType,
+    ListType,
+    TupleType,
+    DictionaryType,
+    BooleanType,
+    NumberVector,
+    StringVector,
+    StringDictionary,
+    DictionaryVector,
+    NumberVectorAlike,
+    NumberArrayAlike,
+    AnyArrayAlike,
+    AnyVectorAlike,
+)
+
 # object that contains the simulation data.
 class MonteCarlo:
 
@@ -12,7 +36,18 @@ class MonteCarlo:
     (OBJECT INFO)
     -------------
 
-    vandal.MonteCarlo - main class.
+    eg. MonteCarlo = vandal.MonteCarlo()
+
+    vandal.MonteCarlo - main class that stores the simulation data.
+
+        * takes 5 additional arguments.
+            list_of_values - pandas dataframe of values.
+            time_seq - desired time sequence.
+            num_sims - desired number of simulation iterations.
+            ref_col (default: ref_col = 0) - column index of the dictionary values.
+            ref_row (default: ref_row = 0) - row index on which the starting point of the simulation is created.
+        * Requirements:
+            data stored as dictionary of key, value pair | list | numpy array | pandas DataFrame.
 
     (OBJECT FUNCTIONS)
     ------------------
@@ -20,14 +55,8 @@ class MonteCarlo:
     eg. vandal.MonteCarlo.function()
 
         .execute() - executes a Monte Carlo simulation on a defined data set.
-            * takes 4 additional arguments.
-            list_of_values - pandas dataframe of values.
-            time_seq - desired time sequence.
-            num_sims - desired number of simulation iterations.
-            ref_value_index (default: ref_value_index = 0) - index on which the starting point of the simulation is created.
-        * Requirements:
-            pandas Python module.
-            pd.DataFrame() defined data set.
+            * takes 1 additional argument.
+                filtered (defualt: filtered = True) - filters the print option and leaves just the return object.
 
         .graph() - plots the Monte Carlo simulation on a graph.
             * takes 5 optional customization arguments. (default: graph_title = 'Monte Carlo simulation', x_title = 'X axis', y_title = 'Y axis', plot_size = (25,10), perform_block = True).
@@ -38,7 +67,8 @@ class MonteCarlo:
                 perform_block (default: perform_block = True) - False/True may be used depending on the IDE requirements.
 
         .get_risk() - calculates the risk of value decrease over time.
-            * takes 1 optional argument (default: risk_sims = 5000).
+            * takes 1 additional argument.
+                risk_sims (default: risk_sims = 5000) - number of simulations to perform the risk percantage.
 
         .get_stats() - shows the statistics of the Monte Carlo simulation.
             * takes no additional arguments.
@@ -47,7 +77,7 @@ class MonteCarlo:
             * takes no additional arguments.
 
         .hist() - plots the histogram of Monte Carlo simulation.
-            * takes 6 optional customization arguments. (default: graph_title = 'Monte Carlo simulation', x_title = 'X axis', y_title = 'Y axis', plot_size = (25,10), perform_block = True, method = 'b').
+            * takes 7 optional customization arguments. (default: graph_title = 'Monte Carlo simulation', x_title = 'X axis', y_title = 'Y axis', plot_size = (25,10), set_bins = None, perform_block = True, method = 'b').
             If method = 'e' is chosen, no customization arguments apply.
                 graph_title - title of the graph.
                 x_title - title of the X axis.
@@ -55,8 +85,15 @@ class MonteCarlo:
                 plot_size - desired size of the graph. eg. - (x_lenght_num, y_lenght_num). - NOTE: values must be inside the parentheses and divided by a comma.
                 perform_block (default: perform_block = True) - False/True may be used depending on the IDE requirements.
                 method - default method is Basic histogram and it's performed by automation. In order to plot Empirical rule histogram add method = 'e' as the last argument. - NOTE: method of a histogram must be placed within quotation marks.
-            * automatically executes the .get_stats(filtered = True) function in order to get standard deviation for the Empirical rule plotting.
+                set_bins - sets the amount of bins of the histogram. (default: set_bins = self.time_seq)
+            * automatically executes the .get_stats() function in order to get standard deviation for the Empirical rule plotting.
 
+    MCapp (EXECUTABLE CLI MODULE)
+    -------------------------
+
+    vandal.MCapp is an executable function that runs the Command Line Interface of the vandal MonteCarlo module.
+        print(help(vandal.MCapp)) in order to see available features.
+        
     '''
 
     # metadata of the used library.
@@ -73,33 +110,64 @@ class MonteCarlo:
     )
 
     # initial launch.
-    def __init__(self):
-        pass
+    def __init__(
+        self, 
+        list_of_values : NumberVectorAlike = None, 
+        time_seq : IntegerType = None, 
+        num_sims : IntegerType = None,
+        ref_col : IntegerType = 0, 
+        ref_row : IntegerType = 0,
+        ) -> ReturnType:
 
-    # class information.
-    def __str__(self):
-        return f'Monte Carlo defining object that stores the configuration data for creating {self.num_sims} simulations in a period of {self.time_seq} time measurement units.'
-
-    # class information.
-    def __repr__(self):
-        return f'Monte Carlo defining object that stores the configuration data for creating {self.num_sims} simulations in a period of {self.time_seq} time measurement units.'
-
-    # executes a Monte Carlo simulation on a defined data set.
-    def execute(self, list_of_values, time_seq, num_sims, ref_value_index = 0):
         self.list_of_values = list_of_values
         self.time_seq = time_seq
         self.num_sims = num_sims
-        self.ref_value_index = ref_value_index
-        print(Fore.GREEN + f'Monte Carlo has been set up for {self.num_sims} simulations in a period of {self.time_seq} time measurement units and executed.' + Fore.RESET)
-        from vandal.hub.toolkit import random_value
-        print(Fore.RED + 'NOTE: Use data with reasonable standard deviation in order to prevent exponential growth of the function that cannot be plotted properly, recognize such abnormal values by a + sign anywhere in the data executed below.' + Fore.RESET)
-        #print('The model that will be able to handle big standard deviations is currently being worked on, thank you for your patience.\n')
+        self.ref_col = ref_col
+        self.ref_row = ref_row
+
         import pandas as pd
+
+        return 
+
+    # class information.
+    def __str__(
+        self,
+        ) -> StringType:
+
+        return f'Monte Carlo defining object that stores the configuration data for creating {self.num_sims} simulations in a period of {self.time_seq} time measurement units.'
+
+    # class information.
+    def __repr__(
+        self,
+        ) -> StringType:
+
+        return f'Monte Carlo defining object that stores the configuration data for creating {self.num_sims} simulations in a period of {self.time_seq} time measurement units.'
+
+    # executes a Monte Carlo simulation on a defined data set.
+    def execute(
+        self,
+        filtered : BooleanType = True,
+        ) -> NumberArrayAlike:
+
+        if filtered == False:
+            print(Fore.GREEN + f'Monte Carlo has been set up for {self.num_sims} simulations in a period of {self.time_seq} time measurement units and executed.' + Fore.RESET)
+            print(Fore.RED + 'NOTE: Use data with reasonable standard deviation in order to prevent exponential growth of the function that cannot be plotted properly, recognize such abnormal values by a + sign anywhere in the data executed below.' + Fore.RESET)
+        
+        from vandal.hub.toolkit import random_value
+        import pandas as pd
+
         # this removes pandas warning of highly fragmented DataFrame for newer pandas versions.
         from warnings import simplefilter
         simplefilter(action = 'ignore', category = pd.errors.PerformanceWarning)
         # end of pandas warning removal block.
-        today_value = self.list_of_values.iloc[self.ref_value_index]
+
+        try:
+            self.list_of_values = pd.DataFrame(self.list_of_values)
+            self.list_of_values = self.list_of_values.iloc[:, self.ref_col]
+        except:
+            raise KeyError('Impossible to reach a defined key, value pair. Data types supported: dictionary, list, numpy array, pandas DataFrame. Make sure to set index row_col on an existing field. Must be of type: int.')
+
+        today_value = self.list_of_values.iloc[self.ref_col]
         data = pd.DataFrame()
         loading = 0
 
@@ -109,7 +177,7 @@ class MonteCarlo:
             index_array = []
             index_array += [today_value * (1 + rand_change)]
 
-            if index_array[count] > (index_array[-1] * 2):
+            if index_array[count] > (index_array[-1] * 3):
                 raise Exception('Variation between data is too big, due to detection of exponentional increase of values or non-sequential data Monte Carlo simulation cannot be executed properly.')
 
             for num_day in range(self.time_seq):
@@ -119,7 +187,7 @@ class MonteCarlo:
                 index_array += [index_array[count] * (1 + rand_change)]
                 count += 1
 
-                if index_array[count] > (index_array[-1] * 2):
+                if index_array[count] > (index_array[-1] * 3):
                     raise Exception('Variation between data is too big, due to detection of exponentional increase of values or non-sequential data Monte Carlo simulation function cannot be executed properly.')
 
             loading += 1
@@ -130,21 +198,31 @@ class MonteCarlo:
         print(end = '\r')
         print(Fore.GREEN + 'Monte Carlo simulation set up and ready to plot.' + Fore.RESET)
         self.results = data
+
         return data
 
     # shows the percentage of Monte Carlo simulation value change for every iteration.
-    def get_change(self):
+    def get_change(
+        self,
+        ) -> NumberArrayAlike:
+
         return self.results.pct_change()
 
     # calculates the risk of negative values occuring.
-    def get_risk(self, risk_sims = 5000):
+    def get_risk(
+        self, 
+        risk_sims : IntegerType = 5000,
+        ) -> NumberType:
+
         import random
         import pandas as pd
-        #This removes pandas warning of highly fragmented DataFrame for newer pandas versions.
+
+        # this removes pandas warning of highly fragmented DataFrame for newer pandas versions.
         from warnings import simplefilter
         simplefilter(action = 'ignore', category = pd.errors.PerformanceWarning)
-        #End of pandas warning removal block.
-        today_value = self.list_of_values.iloc[self.ref_value_index]
+        # end of pandas warning removal block.
+
+        today_value = self.list_of_values.iloc[self.ref_row]
         percent_change = self.list_of_values.pct_change()
         data = pd.DataFrame()
         smaller = []
@@ -163,10 +241,18 @@ class MonteCarlo:
 
         assert (NRisk < 100), '\nTime sequence and/or number of iterations are too low for the proper risk calculation.'
 
-        print(Fore.GREEN + '\nRisk for this option is' + Fore.RESET, round(NRisk,2), Fore.GREEN + '%.' + Fore.RESET)
+        return str(round(NRisk, 2)) + '%'
 
     # plots the Monte Carlo simulation on a graph.
-    def graph(self, graph_title = 'Monte Carlo simulation', x_title = 'X axis', y_title = 'Y axis', plot_size = (25,10), perform_block = True):
+    def graph(
+        self, 
+        graph_title : StringType = 'Monte Carlo simulation', 
+        x_title : StringType = 'X axis', 
+        y_title : StringType = 'Y axis', 
+        plot_size : TupleType = (25,10), 
+        perform_block : BooleanType = True,
+        ) -> GraphType:
+
         print(Fore.GREEN + '\nMonteCarlo() plotting initialized.' + Fore.RESET)
         import matplotlib.pyplot as plt
         plt.figure(figsize = plot_size)
@@ -179,9 +265,16 @@ class MonteCarlo:
         plt.show(block = perform_block)
         print(Fore.GREEN + 'MonteCarlo() plotting finished.' + Fore.RESET)
 
+        return
+
     # shows the statistics of the Monte Carlo simulation.
-    def get_stats(self, filtered = False):
+    def get_stats(
+        self,
+        ) -> AnyArrayAlike:
+        
         import numpy as np
+        import pandas as pd
+
         mean_value = np.mean(self.results.loc[self.time_seq])
         mean_value = round((mean_value),2)
         standard_deviation = round(np.std(self.results.loc[self.time_seq]),2)
@@ -192,17 +285,32 @@ class MonteCarlo:
         minimum_value = round((minimum_value),2)
         self.standard_deviation = standard_deviation
         self.mean_value = mean_value
-        if filtered == False:
-            print(Fore.GREEN + '\nNumber of simulations: ' + Fore.RESET, self.time_seq)
-            print(Fore.GREEN + 'Number of iterations: ' + Fore.RESET, self.num_sims)
-            print(Fore.GREEN + 'Mean value: ' + Fore.RESET, mean_value)
-            print(Fore.GREEN + 'Standard deviation: ' + Fore.RESET, standard_deviation)
-            print(Fore.GREEN + 'Maximum: ' + Fore.RESET, maximum_value)
-            print(Fore.GREEN + 'Minimum: ' + Fore.RESET, minimum_value)
+
+        stats = {
+            'Mean value' : mean_value, 
+            'Standard deviation' : standard_deviation, 
+            'Maximum value ' : maximum_value, 
+            'Minimum value' : minimum_value,
+            }
+
+        stats = pd.DataFrame(stats, index = ['Statistics'])
+        stats = stats.transpose()
+
+        return stats 
 
     # plots the histogram of Monte Carlo simulation.
-    def hist(self, graph_title = 'Histogram of value frequencies', x_title = 'X axis', y_title = 'Y axis', plot_size = (25,10), perform_block = True, **method):
-        self.get_stats(filtered = True)
+    def hist(
+        self, 
+        graph_title : StringType = 'Histogram of value frequencies', 
+        x_title : StringType = 'X axis', 
+        y_title : StringType = 'Y axis', 
+        plot_size : TupleType = (25,10), 
+        perform_block : BooleanType = True,
+        set_bins : IntegerType = None,
+        **method : StringType,
+        ) -> GraphType:
+
+        self.get_stats()
         std_plus = self.mean_value + self.standard_deviation
         std_minus = self.mean_value - self.standard_deviation
         std_plus2 = self.mean_value + (self.standard_deviation * 2)
@@ -233,16 +341,17 @@ class MonteCarlo:
             plt.axvline(x = std_plus3, color = 'g', linestyle = 'dashed')
             plt.axvline(x = std_minus3, color = 'r', linestyle = 'dashed')
 
-        plt.hist(self.results, bins = self.time_seq , ec = 'm')
+        if set_bins == None:
+            set_bins = self.time_seq
+            
+        plt.hist(self.results, bins = set_bins, ec = 'm')
         plt.xlabel(x_title, weight = 'semibold')
         plt.ylabel(y_title, weight= 'semibold')
         plt.show(block = perform_block)
         print(Fore.GREEN + 'Histogram plotting finished.', Fore.RESET)
 
-    # access saved menu particles from function execution.  
-    def get_menu(self):
         return
-        
+
     
 # CLI application.
 def MCapp():
@@ -256,8 +365,11 @@ def MCapp():
         
     '''
 
+    print(Fore.YELLOW + 'MonteCarlo app is initializing...', Fore.RESET)
+    
     # relevant imports.
     import os
+    import pandas as pd
     from vandal.misc._meta import (
         __version__,
         __APPversion__,
@@ -275,11 +387,11 @@ def MCapp():
     print(Fore.YELLOW + 'DATA INPUT OPTIONS', Fore.RESET)
     print('0 | Manual input')
     print('1 | File input\n')
+
     inputchoice = input('Enter the option number: ')
 
     # manual input.
     if inputchoice == '0':
-        import pandas as pd
         iter = True
         print(Fore.RED + '\nWrite any non-number value to stop.', Fore.RESET)
         data = []
@@ -289,6 +401,7 @@ def MCapp():
                 listinput = input('Enter a value: ')
                 listinput = listinput.replace(",", ".")
                 listinput = float(listinput)
+
                 data.append(listinput)
             except:
                 print('')
@@ -300,54 +413,72 @@ def MCapp():
     # file input.
     elif inputchoice == '1':
         inputfile = input('Enter the file destination: ')
+
         data = file_handler(file = inputfile)
 
     # error on input.
     else:
-            raise KeyError('Invalid input, please choose one of the stated options.')
+        raise KeyError('Invalid input, please choose one of the stated options.')
 
     # simulation parameters and execution.
-    MC = MonteCarlo()
     simulations = int(input('Enter number of simulations: ') or 100)
     period = int(input('Enter desired period: ') or 50)
+
+    MC = MonteCarlo(list_of_values = data, num_sims = simulations, time_seq = period)
     print('')
-    executed = MC.execute(list_of_values = data, num_sims = simulations, time_seq = period)
+    executed = MC.execute(filtered = False)
 
     # options after defining the parameters. 
     while True:
         action = input('\n>>> ACTIONS: graph, change, values, stats, risk, hist, help, home: ')
+
         if action == 'graph':
             print('')
+
             title = input('Title: ')
             x_axis = input('X axis title:')
             y_axis = input('Y axis title:')
+
             MC.graph(graph_title = title, x_title = x_axis, y_title = y_axis)
+
         if action == 'change':
             print(Fore.YELLOW + '\nSAVE OPTIONS', Fore.RESET)
             print('0 | csv')
             print('1 | xlsx')
             print('2 | json')
+
             file_type = input('\nEnter the number or name of file type: ')
+
             output = MC.get_change()
+
             try:
-                save_to(file = executed, prefix = 'vandal.MonteCarlo - ' , func_name = 'change', choice = file_type)
+                save_to(file = output, prefix = 'vandal.MonteCarlo - ' , func_name = 'change', choice = file_type)
             except:
                 raise Exception('=== UNABLE TO SAVE, PLEASE SELECT ONE OF THE OPTIONS AND/OR RUN THE TERMINAL AS AN ADMINISTRATOR. ===')
+
         if action == 'values':
             print(Fore.YELLOW + '\nSAVE OPTIONS', Fore.RESET)
             print('0 | csv')
             print('1 | xlsx')
             print('2 | json')
+
             file_type = input('\nEnter the number or name of file type: ')
+
             try:
                 save_to(file = executed, prefix = 'vandal.MonteCarlo - ', func_name = 'values', choice = file_type)
             except:
                 raise Exception('=== UNABLE TO SAVE, PLEASE RUN THE TERMINAL AS AN ADMINISTRATOR. ===')
+
         if action == 'stats' or action == 'statistics':
-            MC.get_stats()
+            print('\n', MC.get_stats())
+
         if action == 'risk':
             sample = int(input('Number of iterations to measure risk on: ') or 5000)
-            MC.get_risk(risk_sims = sample)
+
+            executed_risk = MC.get_risk(risk_sims = sample)
+
+            print(Fore.YELLOW + '\nRisk for this option is' + Fore.RESET, executed_risk[:-1], Fore.YELLOW + '%.' + Fore.RESET)
+
         if action == 'hist' or action == 'histogram':
             print('')
             x_axis = input('X axis title:')
@@ -355,16 +486,21 @@ def MCapp():
             print(Fore.YELLOW + '\nHISTOGRAM METHODS', Fore.RESET)
             print('0 | Basic Histogram')
             print('1 | Empirical Rule Histogram')
+
             method = input('\nEnter the histogram method number: ')
+
             if method == '0':
                 MC.hist(x_title = x_axis, y_title = y_axis)
             elif method == '1':
                 MC.hist(x_title = x_axis, y_title = y_axis, method = 'e')
             else:
                 print(Fore.RED + '=== INVALID METHOD. ===\n', Fore.RESET)
+
         if action == 'home':
             print(Fore.YELLOW + 'Exiting...', Fore.RESET)
+            
             break
+        
         if action == 'help':
             print(Fore.YELLOW + '\nhttps://github.com/dkundih/vandal', Fore.RESET)
 
